crlmmIlluminaV2(sampleSheet=NULL, arrayNames=NULL, ids=NULL, path=".", arrayInfoColNames=list(barcode="SentrixBarcode_A", position="SentrixPosition_A"), highDensity=FALSE, sep="_", fileExt=list(green="Grn.idat", red="Red.idat"), saveDate=FALSE, stripNorm=TRUE, useTarget=TRUE, row.names=TRUE, col.names=TRUE, probs=c(1/3, 1/3, 1/3), DF=6, SNRMin=5, gender=NULL, seed=1, mixtureSampleSize=10^5, eps=0.1, verbose=TRUE, cdfName, sns, recallMin=10, recallRegMin=1000, returnParams=FALSE, badSNP=.7)data.frame containing Illumina sample sheet
information (for required columns, refer to BeadStudio Genotyping
guide - Appendix A).NULL, all arrays that can be found in the
specified working directory will be read in.NULL all probes found on the first array are read in.sampleSheet is specified)
list containing elements 'barcode' which indicates column names in
the sampleSheet which contains the arrayNumber/barcode number
and 'position' which indicates the strip number. In older style
sample sheets, this information is combined (usually in a column
named 'SentrixPosition') and this should be specified as
list(barcode=NULL, position="SentrixPosition")sampleSheet is
specified). If TRUE, array extensions '\_A', '\_B' in
sampleSheet are replaced with 'R01C01', 'R01C02' etc.stripNorm=TRUE).
Should the reference HapMap intensities be used in strip-level normalization?mixtureSampleSize SNPs for mixture model.SnpSet object which contains
assayData slot and
returnParams=TRUE
in the featureData slot.
readIdatFiles and genotyping to reduce memory usage.
Carvalho B, Bengtsson H, Speed TP, Irizarry RA. Exploration, normalization, and genotype calls of high-density oligonucleotide SNP array data. Biostatistics. 2007 Apr;8(2):485-99. Epub 2006 Dec 22. PMID: 17189563.
Carvalho BS, Louis TA, Irizarry RA. Quantifying uncertainty in genotype calls. Bioinformatics. 2010 Jan 15;26(2):242-9.
crlmmIllumina## crlmmOut = crlmmIlluminaV2(samples,path=path,arrayInfoColNames=list(barcode="Chip",position="Section"),
## saveDate=TRUE,cdfName="human370v1c",returnParams=TRUE)
Run the code above in your browser using DataLab