Genotyping of Illumina Infinium II arrays.
Genotyping of Illumina Infinium II arrays. This function provides CRLMM/KRLMM genotypes and confidence scores for the the polymorphic markers and is a required step prior to copy number estimation.
genotypeInf(cnSet, mixtureParams, probs = rep(1/3, 3), SNRMin = 5,
recallMin = 10, recallRegMin = 1000, verbose = TRUE, returnParams =
TRUE, badSNP = 0.7, gender = NULL, DF = 6, cdfName, call.method="crlmm",
trueCalls = NULL)CNSetdata.frame containing mixture model parameters needed for
genotyping. The mixture model parameters are estimated from the
preprocessInf function.
character string indicating which annotation
package to load.assayData elements 'call' and
'callProbability' are updated on disk. Therefore, the genotypes and
confidence scores can be retrieved using accessors for the
CNSet class. The genotype calls and confidence scores are written to
file using ff protocols for I/O. For the most part,
the calls and confidence scores can be accessed as though the
data is in memory through the methods snpCall and
snpCallProbability, respectively.
The genotype calls are stored using an integer representation: 1
- AA, 2 - AB, 3 - BB. Similarly, the call probabilities are
stored using an integer representation to reduce file size using
the transformation 'round(-1000*log2(1-p))', where p is the
probability. The function i2P can be used to convert the
integers back to the scale of probabilities.
An optional trueCalls argument can be provided to KRLMM method
which contains known genotype calls(can contain some NAs) for some
samples and SNPs. This will used to compute KRLMM parameters by calling
vglm function from VGAM package.
The KRLMM method makes use of functions provided in parallel
package to speed up the process. It by default initialises up to
8 clusters. This is configurable by setting up an option named
"krlmm.cores", e.g. options("krlmm.cores" = 16).
crlmm, snpCall,
snpCallProbability, annotationPackages
## See the 'illumina_copynumber' vignette in inst/scripts of
## the source package
Run the code above in your browser using DataLab